MethodChannelBeacon class

An implementation of BeaconPlatform that uses method channels.

Inheritance

Constructors

MethodChannelBeacon()

Properties

eventChannel → EventChannel
The event channel used to interact with the native platform.
final
hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addPeer({required String id, required String name, required String publicKey, required String relayServer, required String version}) → Future<Map>
Pair wallet with dApp using P2PPeer data
override
broadcastResponse({required String id, required String? transactionHash}) → Future<Map>
send broadcast response id beacon request id transactionHash transactionHash using signedTransaction
override
getBeaconResponse() → Stream<String>
listen to beacon response
override
getPeers() → Future<Map>
get list of daPPs connected
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
operationResponse({required String id, required String? transactionHash}) → Future<Map>
send operation response id beacon request id transactionHash transactionHash from the operation
override
pair({required String pairingRequest}) → Future<Map>
Pair wallet with dApp using pairingRequest
override
pause() → Future<Map>
pause connection with dApp support iOS only
override
permissionResponse({required String id, required String? publicKey, required String? address}) → Future<Map>
send permission response id beacon request id publicKey public key of crypto account address wallet address key of crypto account
override
removePeer({required String publicKey}) → Future<Map>
remove connection with single dApp using publicKey
override
removePeers() → Future<Map>
remove all peers
override
respondExample() → Future<void>
example responses to test
override
resume() → Future<Map>
resume connection with dApp support iOS only
override
signPayloadResponse({required String id, required String? signature, SigningType type = SigningType.micheline}) → Future<Map>
send sign payload response id beacon request id signature signature using payload type signing type of payload
override
startBeacon({required String walletName}) → Future<Map>
Initialize beacon with walletName
override
stop() → Future<Map>
stop connection with dApp support iOS only
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited