BeaconRequest class

Class for beacon requests from dApp to wallet

Annotations
  • @JsonSerializable.new()

Constructors

BeaconRequest({RequestType? type, Request? request, List<OperationDetails>? operationDetails, P2PPeer? peer})
Constructor for creating BeaconRequest object.
BeaconRequest.fromJson(Map<String, dynamic> json)
Constructor for deserialize json Map into BeaconRequest object.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
operationDetails ↔ List<OperationDetails>?
Request.operation extra fields list of operations to be performed by wallet
getter/setter pair
peer ↔ P2PPeer?
Request.permission extra fields connected pair data
getter/setter pair
request ↔ Request?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ RequestType?
  • RequestType.permission permission response
  • RequestType.signPayload sign payload response
  • RequestType.operation operation response
  • RequestType.broadcast broadcast response
  • getter/setter pair

    Methods

    noSuchMethod(Invocation invocation) → dynamic
    Invoked when a nonexistent method or property is accessed.
    inherited
    toJson() → Map<String, dynamic>
    Return the serializable of this object into Map.
    toString() → String
    A string representation of this object.
    inherited

    Operators

    operator ==(Object other) → bool
    The equality operator.
    inherited