P2PPeer class

Class for p2p peer data

Annotations
  • @JsonSerializable.new()

Constructors

P2PPeer({required String id, required String name, required String publicKey, required String relayServer, required String version, String? icon, String? appURL, bool? isPaired})
Constructor for creating P2PPeer object.
P2PPeer.fromJson(Map<String, dynamic> json)
Constructor for deserialize json Map into P2PPeer object.
factory

Properties

appURL → String?
url of app
final
hashCode → int
The hash code for this object.
no setterinherited
icon → String?
icon
final
id → String
dApp id
final
isPaired → bool?
pairing status
final
name → String
dApp name
final
publicKey → String
publicKey - unique id for connection
final
relayServer → String
server url
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String
version
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Return the serializable of this object into Map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited